stock
========
simple stock report

The directory structure is as follows:

* ./README.rst -- this file
* ./setup.py -- package installation parameters
* ./steelscript -- package source files files
* ./steelscript/stock/core/ -- core source files
* ./steelscript/stock/appfwk/plugin.py -- plugin information
* ./steelscript/stock/appfwk/datasources/ - directory
* ./steelscript/stock/appfwk/devices/ - directory of devices
* ./steelscript/stock/appfwk/reports/ - directory of reports
* ./steelscript/stock/appfwk/libs/ - helper functions
